@@ -43,6 +43,8 @@
 #include "config.h"
 #endif
 
+#include <string.h>
+
 #include "clutter-gst-enum-types.h"
 #include "clutter-gst-marshal.h"
 #include "clutter-gst-player.h"
@@ -79,8 +81,7 @@ clutter_gst_player_default_init (ClutterGstPlayerIface *iface)
                                 "Playing",
                                 "Whether the player is playing",
                                 FALSE,
-                                CLUTTER_GST_PARAM_READWRITE |
-                                G_PARAM_DEPRECATED);
+                                CLUTTER_GST_PARAM_READWRITE);
   g_object_interface_install_property (iface, pspec);
 
   /**
@@ -93,8 +94,7 @@ clutter_gst_player_default_init (ClutterGstPlayerIface *iface)
                                "Audio Volume",
                                "The volume of the audio",
                                0.0, 1.0, 0.5,
-                               CLUTTER_GST_PARAM_READWRITE |
-                               G_PARAM_DEPRECATED);
+                               CLUTTER_GST_PARAM_READWRITE);
   g_object_interface_install_property (iface, pspec);
 
   /**
@@ -116,10 +116,10 @@ clutter_gst_player_default_init (ClutterGstPlayerIface *iface)
   /**
    * ClutterGstPlayer::new-frame:
    * @player: the #ClutterGstPlayer instance that received the signal
-   * @frame: the #ClutterGstFrame newly receive from the video sink
+   * @frame: the #ClutterGstFrame newly received from the video sink
    *
-   * The ::ready signal is emitted each time the gstreamer pipeline
-   * becomes ready.
+   * The ::new-frame signal is emitted each time a frame is received
+   * from the video sink.
    */
   signals[NEW_FRAME] =
     g_signal_new ("new-frame",
@@ -182,8 +182,8 @@ clutter_gst_player_default_init (ClutterGstPlayerIface *iface)
    * @width: new width of the frames
    * @height: new height of the frames
    *
-   * The ::size-change signal is emitted each time the gstreamer pipeline
-   * becomes ready.
+   * The ::size-change signal is emitted each time the new frame
+   * has different dimensions to the previous frame.
    */
   signals[SIZE_CHANGE] =
     g_signal_new ("size-change",
@@ -390,19 +390,18 @@ clutter_gst_player_update_frame (ClutterGstPlayer *player,
                                  ClutterGstFrame  *new_frame)
 {
   ClutterGstFrame *old_frame = *frame;
+  ClutterGstVideoResolution old_res = { 0, }, new_res = { 0, };
 
   *frame = g_boxed_copy (CLUTTER_GST_TYPE_FRAME, new_frame);
 
-  if (old_frame == NULL ||
-      new_frame->resolution.width != old_frame->resolution.width ||
-      new_frame->resolution.height != old_frame->resolution.height ||
-      new_frame->resolution.par_n != old_frame->resolution.par_n ||
-      new_frame->resolution.par_d != old_frame->resolution.par_d)
-    {
-      g_signal_emit (player, signals[SIZE_CHANGE], 0,
-                     new_frame->resolution.width,
-                     new_frame->resolution.height);
-    }
+  if (old_frame)
+    old_res = old_frame->resolution;
+  if (new_frame)
+    new_res = new_frame->resolution;
+
+  if (memcmp(&old_res, &new_res, sizeof(old_res)) != 0)
+    g_signal_emit (player, signals[SIZE_CHANGE], 0,
+                   new_res.width, new_res.height);
 
   if (old_frame)
     g_boxed_free (CLUTTER_GST_TYPE_FRAME, old_frame);
