@@ -75,8 +75,8 @@ main (int argc, char *argv[])
   GstElement       *capsfilter;
   GstElement       *sink;
   GstCaps          *caps;
+  gchar            *capsstr;
   GstVideoFormat    format;
-  ClutterGstPlayer *player;
 
   result = clutter_gst_init_with_args (&argc,
                                        &argv,
@@ -106,7 +106,7 @@ main (int argc, char *argv[])
   /* Video actor */
   actor = g_object_new (CLUTTER_TYPE_ACTOR,
                         "content", g_object_new (CLUTTER_GST_TYPE_CONTENT,
-                                                 "video-sink", sink,
+                                                 "sink", sink,
                                                  NULL),
                         "width", clutter_actor_get_width (stage),
                         "height", clutter_actor_get_height (stage),
@@ -125,7 +125,9 @@ main (int argc, char *argv[])
 			      NULL);
   g_object_set (capsfilter, "caps", caps, NULL);
 
-  g_printf ("%s: [caps] %s\n", __FILE__, gst_caps_to_string (caps));
+  capsstr = gst_caps_to_string (caps);
+  g_printf ("%s: [caps] %s\n", __FILE__, capsstr);
+  g_free (capsstr);
   gst_bin_add_many (GST_BIN (pipeline), src, capsfilter, sink, NULL);
   result = gst_element_link_many (src, capsfilter, sink, NULL);
   if (result == FALSE)
